[Cmake-commits] CMake branch, next, updated. v2.8.7-2200-g6d403e1

2012-01-23 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  6d403e168707cbdbf81bcb503de07a0a56770ea3 (commit)
   via  b5719fb7272707889030f990d8c6bf66f415c417 (commit)
  from  30c4f7ebf72275894417ec55b5296b701014d6ce (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6d403e168707cbdbf81bcb503de07a0a56770ea3
commit 6d403e168707cbdbf81bcb503de07a0a56770ea3
Merge: 30c4f7e b5719fb
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 14:08:59 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Mon Jan 23 14:08:59 2012 -0500

Merge topic 'improve-findgnutls' into next

b5719fb FindGnuTLS: partly support version selection

diff --cc Modules/FindGnuTLS.cmake
index e69a16b,2e2bf8a..02f2964
--- a/Modules/FindGnuTLS.cmake
+++ b/Modules/FindGnuTLS.cmake
@@@ -35,9 -35,10 +35,10 @@@ IF (NOT WIN32
 # try using pkg-config to get the directories and then use these values
 # in the FIND_PATH() and FIND_LIBRARY() calls
 # also fills in GNUTLS_DEFINITIONS, although that isn't normally useful
 -   FIND_PACKAGE(PkgConfig)
 -   PKG_CHECK_MODULES(PC_GNUTLS gnutls)
 +   FIND_PACKAGE(PkgConfig QUIET)
 +   PKG_CHECK_MODULES(PC_GNUTLS QUIET gnutls)
 SET(GNUTLS_DEFINITIONS ${PC_GNUTLS_CFLAGS_OTHER})
+SET(GNUTLS_VERSION_STRING ${PC_GNUTLS_VERSION})
  ENDIF (NOT WIN32)
  
  FIND_PATH(GNUTLS_INCLUDE_DIR gnutls/gnutls.h

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b5719fb7272707889030f990d8c6bf66f415c417
commit b5719fb7272707889030f990d8c6bf66f415c417
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 19:19:10 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Mon Jan 23 20:07:46 2012 +0100

FindGnuTLS: partly support version selection

For the Un*x systems where we use PkgConfig to find the library we can also
use the version returned from there.

diff --git a/Modules/FindGnuTLS.cmake b/Modules/FindGnuTLS.cmake
index a437a1f..2e2bf8a 100644
--- a/Modules/FindGnuTLS.cmake
+++ b/Modules/FindGnuTLS.cmake
@@ -38,6 +38,7 @@ IF (NOT WIN32)
FIND_PACKAGE(PkgConfig)
PKG_CHECK_MODULES(PC_GNUTLS gnutls)
SET(GNUTLS_DEFINITIONS ${PC_GNUTLS_CFLAGS_OTHER})
+   SET(GNUTLS_VERSION_STRING ${PC_GNUTLS_VERSION})
 ENDIF (NOT WIN32)
 
 FIND_PATH(GNUTLS_INCLUDE_DIR gnutls/gnutls.h
@@ -57,7 +58,9 @@ MARK_AS_ADVANCED(GNUTLS_INCLUDE_DIR GNUTLS_LIBRARY)
 # handle the QUIETLY and REQUIRED arguments and set GNUTLS_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(GnuTLS DEFAULT_MSG GNUTLS_LIBRARY 
GNUTLS_INCLUDE_DIR)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(GnuTLS
+  REQUIRED_VARS GNUTLS_LIBRARY 
GNUTLS_INCLUDE_DIR
+  VERSION_VAR GNUTLS_VERSION_STRING)
 
 IF(GNUTLS_FOUND)
 SET(GNUTLS_LIBRARIES${GNUTLS_LIBRARY})

---

Summary of changes:
 Modules/FindGnuTLS.cmake |5 -
 1 files changed, 4 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2202-g85200d8

2012-01-23 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  85200d8e6e841d94e53674025cadb6a1ed857c53 (commit)
   via  a803a622d052e6b50873f6bf6a3ab224f656333f (commit)
  from  6d403e168707cbdbf81bcb503de07a0a56770ea3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=85200d8e6e841d94e53674025cadb6a1ed857c53
commit 85200d8e6e841d94e53674025cadb6a1ed857c53
Merge: 6d403e1 a803a62
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 14:11:16 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Mon Jan 23 14:11:16 2012 -0500

Merge topic 'improve-findgit' into next

a803a62 FindGit: support version number


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a803a622d052e6b50873f6bf6a3ab224f656333f
commit a803a622d052e6b50873f6bf6a3ab224f656333f
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 19:46:08 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Mon Jan 23 20:10:42 2012 +0100

FindGit: support version number

diff --git a/Modules/FindGit.cmake b/Modules/FindGit.cmake
index 503b640..f89d1af 100644
--- a/Modules/FindGit.cmake
+++ b/Modules/FindGit.cmake
@@ -1,6 +1,7 @@
 # The module defines the following variables:
 #   GIT_EXECUTABLE - path to git command line client
 #   GIT_FOUND - true if the command line client was found
+#   GIT_VERSION_STRING - the version of git found (since CMake 2.8.8)
 # Example usage:
 #   find_package(Git)
 #   if(GIT_FOUND)
@@ -9,6 +10,7 @@
 
 #=
 # Copyright 2010 Kitware, Inc.
+# Copyright 2012 Rolf Eike Beer e...@sf-mail.de
 #
 # Distributed under the OSI-approved BSD License (the License);
 # see accompanying file Copyright.txt for details.
@@ -40,8 +42,21 @@ find_program(GIT_EXECUTABLE
   )
 mark_as_advanced(GIT_EXECUTABLE)
 
+if(GIT_EXECUTABLE)
+  execute_process(COMMAND ${GIT_EXECUTABLE} --version
+  OUTPUT_VARIABLE git_version
+  ERROR_QUIET
+  OUTPUT_STRIP_TRAILING_WHITESPACE)
+  if (git_version MATCHES ^git version [0-9])
+string(REPLACE git version   GIT_VERSION_STRING ${git_version})
+  endif()
+  unset(git_version)
+endif(GIT_EXECUTABLE)
+
 # Handle the QUIETLY and REQUIRED arguments and set GIT_FOUND to TRUE if
 # all listed variables are TRUE
 
 include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-find_package_handle_standard_args(Git DEFAULT_MSG GIT_EXECUTABLE)
+find_package_handle_standard_args(Git
+  REQUIRED_VARS GIT_EXECUTABLE
+  VERSION_VAR GIT_VERSION_STRING)

---

Summary of changes:
 Modules/FindGit.cmake |   17 -
 1 files changed, 16 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2204-gf9ed351

2012-01-23 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  f9ed351ea5313cef177de225ffcec506702844b5 (commit)
   via  be2b108776b46b73508654322e7b4b24f404e191 (commit)
  from  85200d8e6e841d94e53674025cadb6a1ed857c53 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f9ed351ea5313cef177de225ffcec506702844b5
commit f9ed351ea5313cef177de225ffcec506702844b5
Merge: 85200d8 be2b108
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 14:56:21 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Mon Jan 23 14:56:21 2012 -0500

Merge topic 'improve-findcups' into next

be2b108 FindCups: major overhaul


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=be2b108776b46b73508654322e7b4b24f404e191
commit be2b108776b46b73508654322e7b4b24f404e191
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 20:31:38 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Mon Jan 23 20:31:47 2012 +0100

FindCups: major overhaul

This introduces CUPS_VERSION_STRING and ports the module over to use FPHSA 
for
all the benefits that come with it.

diff --git a/Modules/FindCups.cmake b/Modules/FindCups.cmake
index 7e3e10a..3862f7d 100644
--- a/Modules/FindCups.cmake
+++ b/Modules/FindCups.cmake
@@ -4,12 +4,14 @@
 #  CUPS_FOUND - system has Cups
 #  CUPS_INCLUDE_DIR - the Cups include directory
 #  CUPS_LIBRARIES - Libraries needed to use Cups
+#  CUPS_VERSION_STRING - version of Cups found (since CMake 2.8.8)
 #  Set CUPS_REQUIRE_IPP_DELETE_ATTRIBUTE to TRUE if you need a version which 
 #  features this function (i.e. at least 1.1.19)
 
 #=
 # Copyright 2006-2009 Kitware, Inc.
 # Copyright 2006 Alexander Neundorf neund...@kde.org
+# Copyright 2012 Rolf Eike Beer e...@sf-mail.de
 #
 # Distributed under the OSI-approved BSD License (the License);
 # see accompanying file Copyright.txt for details.
@@ -21,36 +23,47 @@
 # (To distribute this file outside of CMake, substitute the full
 #  License text for the above reference.)
 
-INCLUDE(CheckLibraryExists)
+find_path(CUPS_INCLUDE_DIR cups/cups.h )
 
-FIND_PATH(CUPS_INCLUDE_DIR cups/cups.h )
+find_library(CUPS_LIBRARIES NAMES cups )
 
-FIND_LIBRARY(CUPS_LIBRARIES NAMES cups )
+if (CUPS_INCLUDE_DIR AND CUPS_LIBRARIES AND CUPS_REQUIRE_IPP_DELETE_ATTRIBUTE)
+include(CheckLibraryExists)
 
-IF (CUPS_INCLUDE_DIR AND CUPS_LIBRARIES)
-   SET(CUPS_FOUND TRUE)
+# ippDeleteAttribute is new in cups-1.1.19 (and used by kdeprint)
+CHECK_LIBRARY_EXISTS(cups ippDeleteAttribute  
CUPS_HAS_IPP_DELETE_ATTRIBUTE)
+endif (CUPS_INCLUDE_DIR AND CUPS_LIBRARIES AND 
CUPS_REQUIRE_IPP_DELETE_ATTRIBUTE)
 
-   # ippDeleteAttribute is new in cups-1.1.19 (and used by kdeprint)
-   CHECK_LIBRARY_EXISTS(cups ippDeleteAttribute  
CUPS_HAS_IPP_DELETE_ATTRIBUTE)
-   IF (CUPS_REQUIRE_IPP_DELETE_ATTRIBUTE AND NOT CUPS_HAS_IPP_DELETE_ATTRIBUTE)
-  SET(CUPS_FOUND FALSE)
-   ENDIF (CUPS_REQUIRE_IPP_DELETE_ATTRIBUTE AND NOT 
CUPS_HAS_IPP_DELETE_ATTRIBUTE)
+if (CUPS_INCLUDE_DIR AND EXISTS ${CUPS_INCLUDE_DIR}/cups/cups.h)
+file(STRINGS ${CUPS_INCLUDE_DIR}/cups/cups.h cups_version_str
+ REGEX ^#[\t ]*define[\t ]+CUPS_VERSION_(MAJOR|MINOR|PATCH)[\t 
]+[0-9]+$)
 
-ELSE  (CUPS_INCLUDE_DIR AND CUPS_LIBRARIES)
-   SET(CUPS_FOUND FALSE)
-ENDIF (CUPS_INCLUDE_DIR AND CUPS_LIBRARIES)
+unset(CUPS_VERSION_STRING)
+foreach(VPART MAJOR MINOR PATCH)
+foreach(VLINE ${cups_version_str})
+if(VLINE MATCHES ^#[\t ]*define[\t ]+CUPS_VERSION_${VPART})
+string(REGEX REPLACE ^#[\t ]*define[\t 
]+CUPS_VERSION_${VPART}[\t ]+([0-9]+)$ \\1
+   CUPS_VERSION_PART ${VLINE})
+if(CUPS_VERSION_STRING)
+set(CUPS_VERSION_STRING 
${CUPS_VERSION_STRING}.${CUPS_VERSION_PART})
+else(CUPS_VERSION_STRING)
+set(CUPS_VERSION_STRING ${CUPS_VERSION_PART})
+endif(CUPS_VERSION_STRING)
+endif()
+endforeach(VLINE)
+endforeach(VPART)
+endif (CUPS_INCLUDE_DIR AND EXISTS ${CUPS_INCLUDE_DIR}/cups/cups.h)
 
-IF (CUPS_FOUND)
-   IF (NOT Cups_FIND_QUIETLY)
-  MESSAGE(STATUS Found Cups: ${CUPS_LIBRARIES})
-   ENDIF (NOT Cups_FIND_QUIETLY)
-ELSE (CUPS_FOUND)
-   SET(CUPS_LIBRARIES )
-   IF (Cups_FIND_REQUIRED)
-  MESSAGE(FATAL_ERROR Could NOT find Cups)
-   ENDIF (Cups_FIND_REQUIRED)
-ENDIF (CUPS_FOUND)
-  
-  
-MARK_AS_ADVANCED(CUPS_INCLUDE_DIR CUPS_LIBRARIES)
+include(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
+

[Cmake-commits] CMake branch, next, updated. v2.8.7-2206-gfac20b8

2012-01-23 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  fac20b8adb0a9aa338e670957f62eadf756ecc69 (commit)
   via  7f81c48bdd7901a310744c3b65a8a975cd9cf1a6 (commit)
  from  f9ed351ea5313cef177de225ffcec506702844b5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fac20b8adb0a9aa338e670957f62eadf756ecc69
commit fac20b8adb0a9aa338e670957f62eadf756ecc69
Merge: f9ed351 7f81c48
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 14:57:28 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Mon Jan 23 14:57:28 2012 -0500

Merge topic 'improve-findexpat' into next

7f81c48 FindEXPAT: support version number


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=7f81c48bdd7901a310744c3b65a8a975cd9cf1a6
commit 7f81c48bdd7901a310744c3b65a8a975cd9cf1a6
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 20:53:22 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Mon Jan 23 20:54:04 2012 +0100

FindEXPAT: support version number

diff --git a/Modules/FindEXPAT.cmake b/Modules/FindEXPAT.cmake
index 8551fd6..1bf0743 100644
--- a/Modules/FindEXPAT.cmake
+++ b/Modules/FindEXPAT.cmake
@@ -24,10 +24,32 @@ FIND_PATH(EXPAT_INCLUDE_DIR NAMES expat.h)
 # Look for the library.
 FIND_LIBRARY(EXPAT_LIBRARY NAMES expat libexpat)
 
+if (EXPAT_INCLUDE_DIR AND EXISTS ${EXPAT_INCLUDE_DIR}/expat.h)
+file(STRINGS ${EXPAT_INCLUDE_DIR}/expat.h expat_version_str
+ REGEX ^#[\t ]*define[\t ]+XML_(MAJOR|MINOR|MICRO)_VERSION[\t 
]+[0-9]+$)
+
+unset(EXPAT_VERSION_STRING)
+foreach(VPART MAJOR MINOR MICRO)
+foreach(VLINE ${expat_version_str})
+if(VLINE MATCHES ^#[\t ]*define[\t ]+XML_${VPART}_VERSION)
+string(REGEX REPLACE ^#[\t ]*define[\t 
]+XML_${VPART}_VERSION[\t ]+([0-9]+)$ \\1
+   EXPAT_VERSION_PART ${VLINE})
+if(EXPAT_VERSION_STRING)
+set(EXPAT_VERSION_STRING 
${EXPAT_VERSION_STRING}.${EXPAT_VERSION_PART})
+else(EXPAT_VERSION_STRING)
+set(EXPAT_VERSION_STRING ${EXPAT_VERSION_PART})
+endif(EXPAT_VERSION_STRING)
+endif()
+endforeach(VLINE)
+endforeach(VPART)
+endif (EXPAT_INCLUDE_DIR AND EXISTS ${EXPAT_INCLUDE_DIR}/expat.h)
+
 # handle the QUIETLY and REQUIRED arguments and set EXPAT_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(EXPAT DEFAULT_MSG EXPAT_LIBRARY 
EXPAT_INCLUDE_DIR)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(EXPAT
+  REQUIRED_VARS EXPAT_LIBRARY EXPAT_INCLUDE_DIR
+  VERSION_VAR EXPAT_VERSION_STRING)
 
 # Copy the results to the output variables.
 IF(EXPAT_FOUND)

---

Summary of changes:
 Modules/FindEXPAT.cmake |   24 +++-
 1 files changed, 23 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2210-g42dd02e

2012-01-23 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  42dd02e12064aa642ce83aa02c3c0d8a0cd4424b (commit)
   via  0b2e81c63ce6ca9dcf9d775d3f5cd22749e8c134 (commit)
  from  a6810c3c5cb8e0a83bac551c36b5312909f48a8b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=42dd02e12064aa642ce83aa02c3c0d8a0cd4424b
commit 42dd02e12064aa642ce83aa02c3c0d8a0cd4424b
Merge: a6810c3 0b2e81c
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 17:40:42 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Mon Jan 23 17:40:42 2012 -0500

Merge topic 'flex-version' into next

0b2e81c FindFLEX: fix version parsing when the executable is quoted


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0b2e81c63ce6ca9dcf9d775d3f5cd22749e8c134
commit 0b2e81c63ce6ca9dcf9d775d3f5cd22749e8c134
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 23:40:17 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Mon Jan 23 23:40:17 2012 +0100

FindFLEX: fix version parsing when the executable is quoted

diff --git a/Modules/FindFLEX.cmake b/Modules/FindFLEX.cmake
index 6309bc9..586f77a 100644
--- a/Modules/FindFLEX.cmake
+++ b/Modules/FindFLEX.cmake
@@ -94,7 +94,7 @@ IF(FLEX_EXECUTABLE)
 # older versions of flex printed /full/path/to/executable version X.Y
 # newer versions use basename(executable) X.Y
 GET_FILENAME_COMPONENT(FLEX_EXE_NAME ${FLEX_EXECUTABLE} NAME)
-STRING(REGEX REPLACE ^.*${FLEX_EXE_NAME} (version )?([0-9]+[^ ]*)$ \\2
+STRING(REGEX REPLACE ^.*${FLEX_EXE_NAME}\? (version )?([0-9]+[^ ]*)$ 
\\2
   FLEX_VERSION ${FLEX_version_output})
 UNSET(FLEX_EXE_NAME)
   ENDIF()

---

Summary of changes:
 Modules/FindFLEX.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v2.8.7-146-g99180a0

2012-01-23 Thread KWSys Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  99180a0bb27eefd6ef8802c8d5c26a2f6e1cec68 (commit)
  from  86c9604f98b2271401cf7a53c251be51af15278c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=99180a0bb27eefd6ef8802c8d5c26a2f6e1cec68
commit 99180a0bb27eefd6ef8802c8d5c26a2f6e1cec68
Author: KWSys Robot kwro...@kitware.com
AuthorDate: Tue Jan 24 00:05:16 2012 -0500
Commit: KWSys Robot kwro...@kitware.com
CommitDate: Tue Jan 24 00:05:16 2012 -0500

KWSys Nightly Date Stamp

diff --git a/Source/kwsys/kwsysDateStamp.cmake 
b/Source/kwsys/kwsysDateStamp.cmake
index 0ce4f2c..0c1f8ac 100644
--- a/Source/kwsys/kwsysDateStamp.cmake
+++ b/Source/kwsys/kwsysDateStamp.cmake
@@ -18,4 +18,4 @@ SET(KWSYS_DATE_STAMP_YEAR  2012)
 SET(KWSYS_DATE_STAMP_MONTH 01)
 
 # KWSys version date day component.  Format is DD.
-SET(KWSYS_DATE_STAMP_DAY   23)
+SET(KWSYS_DATE_STAMP_DAY   24)

---

Summary of changes:
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2208-ga6810c3

2012-01-23 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  a6810c3c5cb8e0a83bac551c36b5312909f48a8b (commit)
   via  c1b884965f86e2622f55d261259fc2a148035f5b (commit)
  from  fac20b8adb0a9aa338e670957f62eadf756ecc69 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a6810c3c5cb8e0a83bac551c36b5312909f48a8b
commit a6810c3c5cb8e0a83bac551c36b5312909f48a8b
Merge: fac20b8 c1b8849
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 15:47:33 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Mon Jan 23 15:47:33 2012 -0500

Merge topic 'improve-findcurl' into next

c1b8849 FindCURL: support version selection


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c1b884965f86e2622f55d261259fc2a148035f5b
commit c1b884965f86e2622f55d261259fc2a148035f5b
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Mon Jan 23 21:46:56 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Mon Jan 23 21:46:56 2012 +0100

FindCURL: support version selection

diff --git a/Modules/FindCURL.cmake b/Modules/FindCURL.cmake
index 36f3841..517638a 100644
--- a/Modules/FindCURL.cmake
+++ b/Modules/FindCURL.cmake
@@ -1,12 +1,14 @@
 # - Find curl
 # Find the native CURL headers and libraries.
 #
 #  CURL_INCLUDE_DIRS - where to find curl/curl.h, etc.
 #  CURL_LIBRARIES- List of libraries when using curl.
 #  CURL_FOUND- True if curl found.
 
 #=
 # Copyright 2006-2009 Kitware, Inc.
+# Copyright 2012 Rolf Eike Beer e...@sf-mail.de
 #
 # Distributed under the OSI-approved BSD License (the License);
 # see accompanying file Copyright.txt for details.
@@ -32,10 +34,19 @@ FIND_LIBRARY(CURL_LIBRARY NAMES
 )
 MARK_AS_ADVANCED(CURL_LIBRARY)
 
+IF(CURL_INCLUDE_DIR AND EXISTS ${CURL_INCLUDE_DIR}/curl/curlver.h)
+  FILE(STRINGS ${CURL_INCLUDE_DIR}/curl/curlver.h curl_version_str REGEX 
^#define[\t ]+LIBCURL_VERSION[\t ]+\.*\)
+
+  STRING(REGEX REPLACE ^#define[\t ]+LIBCURL_VERSION[\t ]+\([^\]*)\.* 
\\1 CURL_VERSION_STRING ${curl_version_str})
+  UNSET(curl_version_str)
+ENDIF()
+
 # handle the QUIETLY and REQUIRED arguments and set CURL_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(CURL DEFAULT_MSG CURL_LIBRARY 
CURL_INCLUDE_DIR)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(CURL
+  REQUIRED_VARS CURL_LIBRARY CURL_INCLUDE_DIR
+  VERSION_VAR CURL_VERSION_STRING)
 
 IF(CURL_FOUND)
   SET(CURL_LIBRARIES ${CURL_LIBRARY})

---

Summary of changes:
 Modules/FindCURL.cmake |   19 +++
@@ -1,12 +1,14 @@
 # Find the native CURL headers and libraries.
 #
-#  CURL_INCLUDE_DIRS - where to find curl/curl.h, etc.
-#  CURL_LIBRARIES- List of libraries when using curl.
-#  CURL_FOUND- True if curl found.
+#  CURL_INCLUDE_DIRS   - where to find curl/curl.h, etc.
+#  CURL_LIBRARIES  - List of libraries when using curl.
+#  CURL_FOUND  - True if curl found.
+#  CURL_VERSION_STRING - the version of curl found (since CMake 2.8.8)
 
 #=
 1 files changed, 15 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits